/*
 *  Copyright (C) 2000  Mel Gorman (mel@skynet.ie)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
                
#include <stdio.h>
#include <stdlib.h>
#include "vqf.h"
#include "usage.h"

void parseCommandLine(char **argv, int argc, int numOptions, struct optStore option[])
{
  /* Parses out a command line obviously :-) */
  TRACE("parseCommandLine: Starting\n");
  int argCount;
  int optCount;
  
  for (argCount=1;argCount<=argc-1;argCount++)
  {
    optCount=0;
    
    /* Only look at if it's an option of some sort */
    if (argv[argCount][0] != '-') continue;
    
    /* Search through our list of possible options and see if it's one of them */
    while (option[optCount].opt != argv[argCount][1] && optCount < numOptions) optCount++;
    
    /* Print out it's an unknown option if it appears */
    if (optCount == numOptions) printf("Unknown option: %s\n", argv[argCount]);
    else
    {
      /* Else we have an option */
#ifdef DEBUG
      printf("parseCommandLine: Parsing %s\n", argv[argCount]);
#endif
      switch(option[optCount].type)
      {
        /* Option is an integer */
        case OPT_INT: 
          /* Copy the option making sure there is an option available */
          if (argCount+1 != argc)
            *((int *)option[optCount].data) = atoi(argv[++argCount]);
          break;

        /* Option is a string */
        case OPT_STRING:
          /* Copy option making sure one is there */
          if (argCount+1 != argc)
            strcpy((char *)option[optCount].data, argv[++argCount]);
          break;

        /* Option bool */
        case OPT_BOOL:
          *((int *)option[optCount].data) = 1;
          break;

        default:
          printf("Unknown option type\n");
      }
    }
  }
}
