/*  VQF XMMS Plugin
 *  Copyright (C) 2000  Mel Gorman (mel@skynet.ie)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "vqf.h"
#include "vqfencoder.h"
#include "usage.h"

void showusage()
{
  // TRACE("usage: Displaying usage message\n");
  printf("vqfinfo v0.1 (c) Mel Gorman(mel@skynet.ie). Distributed under the GPL.\n\n");

  printf("Usage: vqfinfo [options] filename\n");
  printf("Where\n");
  printf(" -t <title>          Set song title\n");
  printf(" -l <comment>        Set comment\n");
  printf(" -a <artist>         Set artist\n");
  printf(" -c <copyright>      Set who has copyright\n");
  printf(" -e <extra>          Set extra information\n");
  printf(" -q                  Quiet mode\n\n");
  fflush(NULL);
  exit(0);
}
  
int main(int argc, char **argv)
{
  int quietMode=0;
  printf("argc = %d\n", argc);

  /* Check should we show usage message *
  if (argc == 1 || !strcmp(argv[1], "-h") || !strcmp(argv[1], "--help")) showusage();
  if (argc == 1) showusage();

  /* Init header */
  TRACE("main: Initiliazing header\n");
  headerInfo header;
  memset(&header, 0, sizeof(headerInfo));

  /* Reading old header */
  TRACE("main: Reading old header to set defaults\n");
  BFILE *inFile = bopen(argv[argc-1], "r");
  if (!inFile)
  { 
    printf("Failed to open VQF file(%s). Dying a painful death.....\n", argv[argc-1]); 
    return -1; 
  }
  printf("Reading: %s\n", argv[argc-1]);
  if (vqfReadHeader(inFile, &header) == -1) 
  {
    printf("Failed to read VQF header\n");
    return -1;
  }

  bclose(inFile);

  TRACE("main: Building opt struct\n");
  struct optStore options[6];
  SETOPTION(options, 0, 't',    OPT_STRING,     header.Name);
  SETOPTION(options, 1, 'l',    OPT_STRING,     header.Comt);
  SETOPTION(options, 2, 'a',    OPT_STRING,     header.Auth);
  SETOPTION(options, 3, 'c',    OPT_STRING,     header.Cpyr);
  SETOPTION(options, 4, 'e',    OPT_STRING,     header.Extr);
  SETOPTION(options, 5, 'q',    OPT_BOOL,       &quietMode);
  
  TRACE("main: Getting options\n");
  parseCommandLine(argv, argc, 6, options);

  if (quietMode == 0) printf("vqfinfo v0.1 by Mel Gorman. Distributed under the GPL.\n\n");

  TRACE("main: Sending in the header\n");
  vqfWriteHeader(argv[argc-1], &header);
}
